@@ -29,13 +29,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 // Local
 #include <lib/gwenviewconfig.h>
+#include <lib/invisiblebuttongroup.h>
 
 namespace Gwenview
 {
 template<class Ui>
 QWidget *setupPage(Ui &ui)
 {
-    auto *widget = new QWidget;
+    auto widget = new QWidget;
     ui.setupUi(widget);
     widget->layout()->setContentsMargins(0, 0, 0, 0);
     return widget;
@@ -46,11 +47,8 @@ ConfigDialog::ConfigDialog(QWidget *parent)
 {
     setFaceType(KPageDialog::List);
 
-    QWidget *widget;
-    KPageWidgetItem *pageItem;
-
     // General
-    widget = setupPage(mGeneralConfigPage);
+    QWidget *widget = setupPage(mGeneralConfigPage);
 
     mWrapNavigationBehaviorGroup = new InvisibleButtonGroup(widget);
     mWrapNavigationBehaviorGroup->setObjectName(QStringLiteral("kcfg_NavigationEndNotification"));
@@ -69,8 +67,8 @@ ConfigDialog::ConfigDialog(QWidget *parent)
     mThumbnailActionsGroup->addButton(mGeneralConfigPage.selectionOnlyThumbnailActionsRadioButton, int(ThumbnailActions::ShowSelectionButtonOnly));
     mThumbnailActionsGroup->addButton(mGeneralConfigPage.noneThumbnailActionsRadioButton, int(ThumbnailActions::None));
 
-    pageItem = addPage(widget, i18n("General"));
-    pageItem->setIcon(QIcon::fromTheme(QStringLiteral("gwenview")));
+    mGeneralConfigPageItem = addPage(widget, i18n("General"));
+    mGeneralConfigPageItem->setIcon(QIcon::fromTheme(QStringLiteral("gwenview")));
     connect(mGeneralConfigPage.kcfg_JPEGQuality, &QAbstractSlider::valueChanged, this, [=](int value) {
         mGeneralConfigPage.jpegQualitySpinner->setValue(value);
     });
@@ -122,8 +120,8 @@ ConfigDialog::ConfigDialog(QWidget *parent)
     mThumbnailBarOrientationGroup->addButton(mImageViewConfigPage.horizontalRadioButton, int(Qt::Horizontal));
     mThumbnailBarOrientationGroup->addButton(mImageViewConfigPage.verticalRadioButton, int(Qt::Vertical));
 
-    pageItem = addPage(widget, i18n("Image View"));
-    pageItem->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-display-color")));
+    mImageViewConfigPageItem = addPage(widget, i18n("Image View"));
+    mImageViewConfigPageItem->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-display-color")));
 
     // Advanced
     widget = setupPage(mAdvancedConfigPage);
@@ -133,12 +131,24 @@ ConfigDialog::ConfigDialog(QWidget *parent)
     mRenderingIntentGroup->addButton(mAdvancedConfigPage.relativeRenderingIntentRadioButton, int(RenderingIntent::Relative));
     mRenderingIntentGroup->addButton(mAdvancedConfigPage.perceptualRenderingIntentRadioButton, int(RenderingIntent::Perceptual));
 
-    pageItem = addPage(widget, i18n("Advanced"));
-    pageItem->setIcon(QIcon::fromTheme(QStringLiteral("preferences-other")));
+    mAdvancedConfigPageItem = addPage(widget, i18n("Advanced"));
+    mAdvancedConfigPageItem->setIcon(QIcon::fromTheme(QStringLiteral("preferences-other")));
     mAdvancedConfigPage.cacheHelpLabel->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
     mAdvancedConfigPage.perceptualHelpLabel->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
     mAdvancedConfigPage.relativeHelpLabel->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
     mAdvancedConfigPage.colorProfileHelpLabel->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
 }
 
+void ConfigDialog::setCurrentPage(int page)
+{
+    switch (page) {
+    case 1:
+        return KPageDialog::setCurrentPage(mImageViewConfigPageItem);
+    case 2:
+        return KPageDialog::setCurrentPage(mAdvancedConfigPageItem);
+    default:
+        return KPageDialog::setCurrentPage(mGeneralConfigPageItem);
+    }
+}
+
 } // namespace
