@@ -25,6 +25,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 // KF
 #include <KDirLister>
+#include <KIO/Job>
+#include <KJobUiDelegate>
+#include <kio_version.h>
 
 // Local
 #include "gwenview_importer_debug.h"
@@ -34,7 +37,7 @@ namespace Gwenview
 {
 struct DocumentDirFinderPrivate {
     QUrl mRootUrl;
-    KDirLister *mDirLister;
+    KDirLister *mDirLister = nullptr;
 
     QUrl mFoundDirUrl;
 };
@@ -46,6 +49,18 @@ DocumentDirFinder::DocumentDirFinder(const QUrl &rootUrl)
     d->mDirLister = new KDirLister(this);
     connect(d->mDirLister, &KCoreDirLister::itemsAdded, this, &DocumentDirFinder::slotItemsAdded);
     connect(d->mDirLister, SIGNAL(completed()), SLOT(slotCompleted()));
+    connect(d->mDirLister, &KCoreDirLister::jobError, this, [this](KIO::Job *job) {
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 96, 0)
+        if (job->error() == KIO::Error::ERR_CANNOT_CREATE_WORKER) {
+#else
+    if (job->error() == KIO::Error::ERR_CANNOT_CREATE_SLAVE) {
+#endif
+            Q_EMIT protocollNotSupportedError();
+        } else {
+            job->uiDelegate()->showErrorMessage();
+        }
+    });
+    d->mDirLister->setAutoErrorHandlingEnabled(false);
     d->mDirLister->openUrl(rootUrl);
 }
 
@@ -92,7 +107,7 @@ void DocumentDirFinder::slotItemsAdded(const QUrl &dir, const KFileItemList &lis
 void DocumentDirFinder::slotCompleted()
 {
     if (d->mFoundDirUrl.isValid()) {
-        QUrl url = d->mFoundDirUrl;
+        const QUrl url = d->mFoundDirUrl;
         d->mFoundDirUrl.clear();
         d->mDirLister->openUrl(url);
     } else {
