@@ -23,6 +23,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 // Qt
 #include <QDate>
+#include <QGuiApplication>
 #include <QHBoxLayout>
 #include <QLocale>
 
@@ -36,13 +37,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 namespace Gwenview
 {
 struct DateWidgetPrivate {
-    DateWidget *q;
+    DateWidget *q = nullptr;
 
     QDate mDate;
-    KDatePicker *mDatePicker;
-    StatusBarToolButton *mPreviousButton;
-    StatusBarToolButton *mDateButton;
-    StatusBarToolButton *mNextButton;
+    KDatePicker *mDatePicker = nullptr;
+    StatusBarToolButton *mPreviousButton = nullptr;
+    StatusBarToolButton *mDateButton = nullptr;
+    StatusBarToolButton *mNextButton = nullptr;
 
     void setupDatePicker()
     {
@@ -80,8 +81,8 @@ DateWidget::DateWidget(QWidget *parent)
 
     d->mPreviousButton = new StatusBarToolButton;
     d->mPreviousButton->setGroupPosition(StatusBarToolButton::GroupLeft);
-    // FIXME: RTL
-    d->mPreviousButton->setIcon(QIcon::fromTheme(QStringLiteral("go-previous")));
+    d->mPreviousButton->setIcon(
+        QIcon::fromTheme(QGuiApplication::layoutDirection() == Qt::LeftToRight ? QStringLiteral("go-previous") : QStringLiteral("go-previous-symbolic-rtl")));
     connect(d->mPreviousButton, &StatusBarToolButton::clicked, this, &DateWidget::goToPrevious);
 
     d->mDateButton = new StatusBarToolButton;
@@ -90,10 +91,11 @@ DateWidget::DateWidget(QWidget *parent)
 
     d->mNextButton = new StatusBarToolButton;
     d->mNextButton->setGroupPosition(StatusBarToolButton::GroupRight);
-    d->mNextButton->setIcon(QIcon::fromTheme(QStringLiteral("go-next")));
+    d->mNextButton->setIcon(
+        QIcon::fromTheme(QGuiApplication::layoutDirection() == Qt::LeftToRight ? QStringLiteral("go-next") : QStringLiteral("go-next-symbolic-rtl")));
     connect(d->mNextButton, &StatusBarToolButton::clicked, this, &DateWidget::goToNext);
 
-    auto *layout = new QHBoxLayout(this);
+    auto layout = new QHBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
     layout->addWidget(d->mPreviousButton);
