@@ -64,11 +64,11 @@ struct RedEyeReductionWidget : public QWidget, public Ui_RedEyeReductionWidget {
 };
 
 struct RedEyeReductionToolPrivate {
-    RedEyeReductionTool *q;
+    RedEyeReductionTool *q = nullptr;
     RedEyeReductionTool::Status mStatus;
     QPointF mCenter;
     int mDiameter;
-    RedEyeReductionWidget *mToolWidget;
+    RedEyeReductionWidget *mToolWidget = nullptr;
 
     void setupToolWidget()
     {
@@ -113,12 +113,12 @@ void RedEyeReductionTool::paint(QPainter *painter)
     if (d->mStatus == NotSet) {
         return;
     }
-    QRectF docRectF = d->rectF();
+    const QRectF docRectF = d->rectF();
     imageView()->document()->waitUntilLoaded();
 
-    QRect docRect = docRectF.toAlignedRect();
+    const QRect docRect = docRectF.toAlignedRect();
     QImage img = imageView()->document()->image().copy(docRect);
-    QRectF imgRectF(docRectF.left() - docRect.left(), docRectF.top() - docRect.top(), docRectF.width(), docRectF.height());
+    const QRectF imgRectF(docRectF.left() - docRect.left(), docRectF.top() - docRect.top(), docRectF.width(), docRectF.height());
     RedEyeReductionImageOperation::apply(&img, imgRectF);
 
     const QRectF viewRectF = imageView()->mapToView(docRectF);
@@ -209,7 +209,7 @@ void RedEyeReductionTool::slotApplyClicked()
         qCWarning(GWENVIEW_LIB_LOG) << "invalid rect";
         return;
     }
-    auto *op = new RedEyeReductionImageOperation(docRectF);
+    auto op = new RedEyeReductionImageOperation(docRectF);
     Q_EMIT imageOperationRequested(op);
 
     d->mStatus = NotSet;
